@@ -9,8 +9,8 @@ if cmd_subfolder_grid not in sys.path:
     sys.path.insert(0, cmd_subfolder_grid)
 
 from test import Test
-from .parser import Parser
-from .grid import Grid
+from parser import Parser
+from grid import Grid
 
 
 class EnvBuilder:
