@@ -2,11 +2,10 @@ import os, sys, inspect
 import pkg_resources
 
 #Pour inclure les fichiers de l'environnement
-'''
-cmd_subfolder_grid = os.path.realpath(os.path.abspath(os.path.join(os.path.split(inspect.getfile( inspect.currentframe() ))[0],"Grid")))
+cmd_subfolder_grid = os.path.realpath(os.path.abspath(os.path.join(os.path.split(inspect.getfile( inspect.currentframe() ))[0],"grid")))
 if cmd_subfolder_grid not in sys.path:
     sys.path.insert(0, cmd_subfolder_grid)
-'''
+
 from grid import Grid
 from parser import Parser
 
